From ef777b73dcd53f7341c32fdf04b39906c86087f3 Mon Sep 17 00:00:00 2001
From: Jose Antonio Ortega Ruiz <jao@gnu.org>
Date: Sun, 23 May 2010 23:23:46 +0200
Subject: PLT: Completing the .ss -> .rkt transition.

---
 scheme/plt/geiser.rkt             |  6 +++---
 scheme/plt/geiser/autodoc.rkt     |  4 ++--
 scheme/plt/geiser/completions.rkt |  6 +++---
 scheme/plt/geiser/enter.rkt       |  4 ++--
 scheme/plt/geiser/eval.rkt        |  4 ++--
 scheme/plt/geiser/locations.rkt   |  6 +++---
 scheme/plt/geiser/main.rkt        |  6 ++----
 scheme/plt/geiser/modules.rkt     | 15 +++++++++------
 scheme/plt/geiser/user.rkt        |  4 ++--
 scheme/plt/geiser/utils.rkt       |  6 +++---
 10 files changed, 31 insertions(+), 30 deletions(-)

(limited to 'scheme')

diff --git a/scheme/plt/geiser.rkt b/scheme/plt/geiser.rkt
index 29dff2a..6634bfd 100644
--- a/scheme/plt/geiser.rkt
+++ b/scheme/plt/geiser.rkt
@@ -1,6 +1,6 @@
-;;; geiser.ss -- entry point
+;;; geiser.rkt -- entry point
 
-;; Copyright (C) 2009 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -19,4 +19,4 @@
 
 (require geiser/user)
 
-;;; geiser.ss ends here
+;;; geiser.rkt ends here
diff --git a/scheme/plt/geiser/autodoc.rkt b/scheme/plt/geiser/autodoc.rkt
index c317d5c..d6fffbb 100644
--- a/scheme/plt/geiser/autodoc.rkt
+++ b/scheme/plt/geiser/autodoc.rkt
@@ -1,4 +1,4 @@
-;;; autodoc.ss -- suport for autodoc echo
+;;; autodoc.rkt -- suport for autodoc echo
 
 ;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
@@ -186,4 +186,4 @@
                                define-syntax define set! define-struct)))))
     (hash-remove! signatures path)))
 
-;;; autodoc.ss ends here
+;;; autodoc.rkt ends here
diff --git a/scheme/plt/geiser/completions.rkt b/scheme/plt/geiser/completions.rkt
index bf6b1c9..e0ff239 100644
--- a/scheme/plt/geiser/completions.rkt
+++ b/scheme/plt/geiser/completions.rkt
@@ -1,6 +1,6 @@
-;;; completions.ss -- completion support
+;;; completions.rkt -- completion support
 
-;; Copyright (C) 2009 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -28,4 +28,4 @@
 (define (module-completions prefix)
   (filter-prefix prefix (module-list) #f))
 
-;;; completions.ss ends here
+;;; completions.rkt ends here
diff --git a/scheme/plt/geiser/enter.rkt b/scheme/plt/geiser/enter.rkt
index b81ba48..705482d 100644
--- a/scheme/plt/geiser/enter.rkt
+++ b/scheme/plt/geiser/enter.rkt
@@ -1,4 +1,4 @@
-;;; enter.ss -- custom module loaders
+;;; enter.rkt -- custom module loaders
 
 ;; Copyright (C) 2010 Jose Antonio Ortega Ruiz
 
@@ -100,4 +100,4 @@
                            path
                            (mod-name mod)))))))))))))))
 
-;;; enter.ss ends here
+;;; enter.rkt ends here
diff --git a/scheme/plt/geiser/eval.rkt b/scheme/plt/geiser/eval.rkt
index 79f212e..cef6130 100644
--- a/scheme/plt/geiser/eval.rkt
+++ b/scheme/plt/geiser/eval.rkt
@@ -1,4 +1,4 @@
-;;; eval.ss -- evaluation
+;;; eval.rkt -- evaluation
 
 ;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
@@ -78,4 +78,4 @@
     (printf "racket@~a" (namespace->module-name ns))
     (builtin-reader)))
 
-;;; eval.ss ends here
+;;; eval.rkt ends here
diff --git a/scheme/plt/geiser/locations.rkt b/scheme/plt/geiser/locations.rkt
index dea93c6..bae7122 100644
--- a/scheme/plt/geiser/locations.rkt
+++ b/scheme/plt/geiser/locations.rkt
@@ -1,6 +1,6 @@
-;;; locations.ss -- locating symbols
+;;; locations.rkt -- locating symbols
 
-;; Copyright (C) 2009 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -51,4 +51,4 @@
   (make-location sym (module-spec->path-name sym) 1))
 
 
-;;; locations.ss ends here
+;;; locations.rkt ends here
diff --git a/scheme/plt/geiser/main.rkt b/scheme/plt/geiser/main.rkt
index f157ac6..d6ff332 100644
--- a/scheme/plt/geiser/main.rkt
+++ b/scheme/plt/geiser/main.rkt
@@ -1,4 +1,4 @@
-;;; main.ss -- exported interface for emacs
+;;; main.rkt -- exported interface for emacs
 
 ;; Copyright (C) 2010 Jose Antonio Ortega Ruiz
 
@@ -9,8 +9,6 @@
 
 ;; Start date: Wed Mar 31, 2010 21:14
 
-;;; main.ss ends here
-
 #lang scheme/base
 
 (provide geiser:eval
@@ -46,4 +44,4 @@
 (define geiser:module-exports module-exports)
 (define geiser:macroexpand macroexpand)
 
-;;; main.ss ends here
+;;; main.rkt ends here
diff --git a/scheme/plt/geiser/user.rkt b/scheme/plt/geiser/user.rkt
index 48b7dd5..19b1e1b 100644
--- a/scheme/plt/geiser/user.rkt
+++ b/scheme/plt/geiser/user.rkt
@@ -1,4 +1,4 @@
-;;; user.ss -- global bindings visible to geiser users
+;;; user.rkt -- global bindings visible to geiser users
 
 ;; Copyright (C) 2010 Jose Antonio Ortega Ruiz
 
@@ -53,5 +53,5 @@
 
 (init)
 
-;;; user.ss ends here
+;;; user.rkt ends here
 
diff --git a/scheme/plt/geiser/utils.rkt b/scheme/plt/geiser/utils.rkt
index ff8e695..f6c739c 100644
--- a/scheme/plt/geiser/utils.rkt
+++ b/scheme/plt/geiser/utils.rkt
@@ -1,6 +1,6 @@
-;;; utils.ss -- generic utilities
+;;; utils.rkt -- generic utilities
 
-;; Copyright (C) 2009 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the Modified BSD License. You should
@@ -24,4 +24,4 @@
 (define keyword->symbol (compose string->symbol keyword->string))
 (define (symbol->keyword sym) (string->keyword (format "~a" sym)))
 
-;;; utils.ss ends here
+;;; utils.rkt ends here
diff --git a/scheme/plt/geiser/modules.rkt b/scheme/plt/geiser/modules.rkt
index 829cf77..2de8e35 100644
--- a/scheme/plt/geiser/modules.rkt
+++ b/scheme/plt/geiser/modules.rkt
@@ -1,4 +1,4 @@
 ;;; modules.ss -- module metadata
 
 ;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
 
@@ -87,16 +87,19 @@
 (define path->symbol (compose string->symbol path->string))
 
 (define (path->entry path)
-  (and (bytes=? (or (filename-extension path) #"") #"ss")
-       (let ((path (path->string path)))
-         (substring path 0 (- (string-length path) 3)))))
+  (let ((ext (filename-extension path)))
+    (and ext
+         (or (bytes=? ext #"rkt") (bytes=? ext #"ss"))
+         (let ((path (path->string path)))
+           (substring path 0 (- (string-length path) 3))))))
 
 (define (visit-module-path path kind acc)
   (case kind
     ((file) (let ((entry (path->entry path)))
               (if entry (cons entry acc) acc)))
     ((dir) (cond ((skippable-dir? path) (values acc #f))
-                 ((file-exists? (build-path path "main.ss"))
+                 ((or (file-exists? (build-path path "main.rkt"))
+                      (file-exists? (build-path path "main.ss")))
                   (cons (path->string path) acc))
                  (else acc)))
     (else acc)))
@@ -144,4 +147,4 @@
 
 (startup)
 
 ;;; modules.ss ends here
@@ -1,4 +1,4 @@
-;;; modules.ss -- module metadata
+;;; modules.rkt -- module metadata
 
 ;; Copyright (C) 2009, 2010 Jose Antonio Ortega Ruiz
@@ -144,4 +147,4 @@
 (startup)
 
-;;; modules.ss ends here
+;;; modules.rkt ends here
-- 
cgit v1.2.3